@@ -2,9 +2,9 @@
 The `~plasmapy.formulary` subpackage contains commonly used formulae
 from plasma science.
 """
-# __all__ & __aliases__ will be auto populated below
 __all__ = []
 __aliases__ = []
+__lite_funcs__ = []
 
 from plasmapy.formulary.braginskii import *
 from plasmapy.formulary.collisions import *
@@ -12,12 +12,16 @@ from plasmapy.formulary.dielectric import *
 from plasmapy.formulary.dimensionless import *
 from plasmapy.formulary.distribution import *
 from plasmapy.formulary.drifts import *
+from plasmapy.formulary.frequencies import *
 from plasmapy.formulary.ionization import *
+from plasmapy.formulary.lengths import *
 from plasmapy.formulary.magnetostatics import *
 from plasmapy.formulary.mathematics import *
-from plasmapy.formulary.parameters import *
+from plasmapy.formulary.misc import *
 from plasmapy.formulary.quantum import *
+from plasmapy.formulary.radiation import *
 from plasmapy.formulary.relativity import *
+from plasmapy.formulary.speeds import *
 
 # auto populate __all__
 for obj_name in list(globals()):
@@ -25,7 +29,11 @@ for obj_name in list(globals()):
         __all__.append(obj_name)
 __all__.sort()
 
-# auto populate __aliases__
+# Put non-formulary imports here so that they don't get included in __all__
+
+import contextlib  # isort:skip
+
+# auto populate __aliases__ & __lite_funcs__
 for modname in (
     "braginskii",
     "collisions",
@@ -33,19 +41,31 @@ for modname in (
     "dimensionless",
     "distribution",
     "drifts",
+    "frequencies",
     "ionization",
+    "lengths",
     "magnetostatics",
     "mathematics",
+    "misc",
     "parameters",
     "quantum",
+    "radiation",
     "relativity",
+    "speeds",
 ):
     try:
         obj = globals()[modname]
+    except KeyError:  # coverage: ignore
+        continue
+
+    with contextlib.suppress(AttributeError):
         __aliases__.extend(obj.__aliases__)
-    except (KeyError, AttributeError):
-        pass
-__aliases__.sort()
+
+    with contextlib.suppress(AttributeError):
+        __lite_funcs__.extend(obj.__lite_funcs__)
+
+__aliases__ = list(sorted(set(__aliases__)))
+__lite_funcs__ = list(sorted(set(__lite_funcs__)))
 
 # cleanup namespace
-del modname, obj, obj_name
+del contextlib, modname, obj, obj_name
