@@ -17,10 +17,12 @@ import astropy.units as u
 import numpy as np
 
 from astropy.constants.si import c, e, eps0, h, hbar, k_B, m_e
+from lmfit import minimize, Parameters
 
 from plasmapy import particles
 from plasmapy.formulary import mathematics
 from plasmapy.formulary.relativity import Lorentz_factor
+from plasmapy.particles.exceptions import InvalidParticleError
 from plasmapy.utils import RelativityError
 from plasmapy.utils.decorators import validate_quantities
 
@@ -53,9 +55,9 @@ def deBroglie_wavelength(V: u.m / u.s, particle) -> u.m:
     V : `~astropy.units.Quantity`
         Particle velocity in units convertible to meters per second.
 
-    particle : `str`, `~plasmapy.particles.Particle`, or `~astropy.units.Quantity`
+    particle : `str`, `~plasmapy.particles.particle_class.Particle`, or `~astropy.units.Quantity`
         An instance of `~plasmapy.particles.particle_class.Particle`, or
-        an equvalent representation (e.g., ``'e'``, ``'p'``, ``'D+'``, or
+        an equivalent representation (e.g., ``'e'``, ``'p'``, ``'D+'``, or
         ``'He-4 1+'``), for the particle of interest, or the particle
         mass in units convertible to kg.  If a
         `~plasmapy.particles.particle_class.Particle` instance is given, then the
@@ -106,17 +108,17 @@ def deBroglie_wavelength(V: u.m / u.s, particle) -> u.m:
         try:
             # TODO: Replace with more general routine!
             m = particles.particle_mass(particle)
-        except Exception:
+        except InvalidParticleError:
             raise ValueError("Unable to find particle mass.")
     else:
         try:
             m = particle.to(u.kg)
-        except Exception:
+        except u.UnitConversionError as e:
             raise u.UnitConversionError(
                 "The second argument for deBroglie_wavelength must be either a "
                 "representation of a particle or a"
                 " Quantity with units of mass."
-            )
+            ) from e
 
     if V.size > 1:
 
@@ -124,12 +126,10 @@ def deBroglie_wavelength(V: u.m / u.s, particle) -> u.m:
         indices = V.value != 0
         lambda_dBr[indices] = h / (m * V[indices] * Lorentz_factor(V[indices]))
 
+    elif V == 0 * u.m / u.s:
+        lambda_dBr = np.inf * u.m
     else:
-
-        if V == 0 * u.m / u.s:
-            lambda_dBr = np.inf * u.m
-        else:
-            lambda_dBr = h / (Lorentz_factor(V) * m * V)
+        lambda_dBr = h / (Lorentz_factor(V) * m * V)
 
     return lambda_dBr
 
@@ -189,8 +189,7 @@ def thermal_deBroglie_wavelength(T_e: u.K) -> u.m:
     >>> thermal_deBroglie_wavelength(1 * u.eV)
     <Quantity 6.9193675e-10 m>
     """
-    lambda_dbTh = h / np.sqrt(2 * np.pi * m_e * k_B * T_e)
-    return lambda_dbTh
+    return h / np.sqrt(2 * np.pi * m_e * k_B * T_e)
 
 
 lambdaDB_th_ = thermal_deBroglie_wavelength
@@ -200,7 +199,7 @@ lambdaDB_th_ = thermal_deBroglie_wavelength
 @validate_quantities(
     n_e={"can_be_negative": False}, validations_on_return={"can_be_negative": False}
 )
-def Fermi_energy(n_e: u.m ** -3) -> u.J:
+def Fermi_energy(n_e: u.m**-3) -> u.J:
     r"""
     Calculate the kinetic energy in a degenerate electron gas.
 
@@ -256,8 +255,7 @@ def Fermi_energy(n_e: u.m ** -3) -> u.J:
     <Quantity 1.2586761e-18 J>
     """
     coeff = (np.pi * hbar) ** 2 / (2 * m_e)
-    energy_F = coeff * (3 * n_e / np.pi) ** (2 / 3)
-    return energy_F
+    return coeff * (3 * n_e / np.pi) ** (2 / 3)
 
 
 Ef_ = Fermi_energy
@@ -267,7 +265,7 @@ Ef_ = Fermi_energy
 @validate_quantities(
     n_e={"can_be_negative": False}, validations_on_return={"can_be_negative": False}
 )
-def Thomas_Fermi_length(n_e: u.m ** -3) -> u.m:
+def Thomas_Fermi_length(n_e: u.m**-3) -> u.m:
     r"""
     Calculate the exponential scale length for charge screening
     for cold and dense plasmas.
@@ -320,8 +318,8 @@ def Thomas_Fermi_length(n_e: u.m ** -3) -> u.m:
 
     See Also
     --------
-    Fermi_energy
-    plasmapy.formulary.Debye_length
+    ~plasmapy.formulary.quantum.Fermi_energy
+    ~plasmapy.formulary.lengths.Debye_length
 
     Examples
     --------
@@ -331,14 +329,13 @@ def Thomas_Fermi_length(n_e: u.m ** -3) -> u.m:
 
     """
     energy_F = Fermi_energy(n_e)
-    lambda_TF = np.sqrt(2 * eps0 * energy_F / (3 * n_e * e ** 2))
-    return lambda_TF
+    return np.sqrt(2 * eps0 * energy_F / (3 * n_e * e**2))
 
 
 @validate_quantities(
     n={"can_be_negative": False}, validations_on_return={"can_be_negative": False}
 )
-def Wigner_Seitz_radius(n: u.m ** -3) -> u.m:
+def Wigner_Seitz_radius(n: u.m**-3) -> u.m:
     r"""
     Calculate the Wigner-Seitz radius, which approximates the inter-particle
     spacing.
@@ -363,7 +360,7 @@ def Wigner_Seitz_radius(n: u.m ** -3) -> u.m:
     Raises
     ------
     `TypeError`
-        If argument is not a ~astropy.units.Quantity.
+        If argument is not a `~astropy.units.Quantity`.
 
     `~astropy.units.UnitConversionError`
         If argument is in incorrect units.
@@ -387,7 +384,7 @@ def Wigner_Seitz_radius(n: u.m ** -3) -> u.m:
 
     See Also
     --------
-    Fermi_energy
+    ~plasmapy.formulary.quantum.Fermi_energy
 
     Examples
     --------
@@ -396,8 +393,7 @@ def Wigner_Seitz_radius(n: u.m ** -3) -> u.m:
     <Quantity 1.33650462e-10 m>
 
     """
-    radius = (3 / (4 * np.pi * n)) ** (1 / 3)
-    return radius
+    return (3 / (4 * np.pi * n)) ** (1 / 3)
 
 
 # TODO: remove NotImplementedError and 'doctest: +SKIP' when the following issues are addressed...
@@ -407,7 +403,7 @@ def Wigner_Seitz_radius(n: u.m ** -3) -> u.m:
     n_e={"can_be_negative": False},
     T={"can_be_negative": False, "equivalencies": u.temperature_energy()},
 )
-def chemical_potential(n_e: u.m ** -3, T: u.K) -> u.dimensionless_unscaled:
+def chemical_potential(n_e: u.m**-3, T: u.K) -> u.dimensionless_unscaled:
     r"""
     Calculate the ideal chemical potential.
 
@@ -416,7 +412,7 @@ def chemical_potential(n_e: u.m ** -3, T: u.K) -> u.dimensionless_unscaled:
     n_e : `~astropy.units.Quantity`
         Electron number density.
 
-    T : ~astropy.units.Quantity
+    T : `~astropy.units.Quantity`
         The temperature.
 
     Returns
@@ -443,7 +439,7 @@ def chemical_potential(n_e: u.m ** -3, T: u.K) -> u.dimensionless_unscaled:
 
     Notes
     -----
-    The ideal chemical potential is given by [1]_:
+    The ideal chemical potential is given by :cite:p:`bonitz:1998`\ :
 
     .. math::
         χ_a = I_{1/2}(β μ_a^{ideal})
@@ -456,29 +452,25 @@ def chemical_potential(n_e: u.m ** -3, T: u.K) -> u.dimensionless_unscaled:
     The definition for the ideal chemical potential is implicit, so it must
     be obtained numerically by solving for the Fermi integral for values
     of chemical potential approaching the degeneracy parameter. Since values
-    returned from the Fermi_integral are complex, a nonlinear
-    Levenberg-Marquardt least squares method is used to iteratively approach
-    a value of :math:`μ` which minimizes
+    returned from the `~plasmapy.formulary.mathematics.Fermi_integral`
+    are complex, a nonlinear Levenberg-Marquardt least squares method is
+    used to iteratively approach a value of :math:`μ` which minimizes
     :math:`I_{1/2}(β μ_a^{ideal}) - χ_a`
 
     This function returns :math:`β μ^{ideal}` the dimensionless
     ideal chemical potential.
 
-    Warning: at present this function is limited to relatively small
-    arguments due to limitations in the `~mpmath` package's implementation
-    of `~mpmath.polylog`, which PlasmaPy uses in calculating the Fermi
-    integral.
-
-    References
-    ----------
-    .. [1] Bonitz, Michael. Quantum kinetic theory. Stuttgart: Teubner, 1998.
+    Warnings
+    --------
+    At present this function is limited to relatively small arguments
+    due to limitations in the ``mpmath.polylog``, which PlasmaPy uses in
+    calculating the Fermi integral.
 
     Examples
     --------
     >>> from astropy import units as u
     >>> chemical_potential(n_e=1e21*u.cm**-3,T=11000*u.K)  # doctest: +SKIP
     <Quantity 2.00039985e-12>
-
     """
 
     raise NotImplementedError(
@@ -490,7 +482,7 @@ def chemical_potential(n_e: u.m ** -3, T: u.K) -> u.dimensionless_unscaled:
     # deBroglie wavelength
     lambdaDB = thermal_deBroglie_wavelength(T)
     # degeneracy parameter
-    degen = (n_e * lambdaDB ** 3).to(u.dimensionless_unscaled)
+    degen = (n_e * lambdaDB**3).to(u.dimensionless_unscaled)
 
     def residual(params, data, eps_data):
         """Residual function for fitting parameters to Fermi_integral."""
@@ -502,13 +494,6 @@ def chemical_potential(n_e: u.m ** -3, T: u.K) -> u.dimensionless_unscaled:
 
     # setting parameters for fitting along with bounds
     alphaGuess = 1 * u.dimensionless_unscaled
-    try:
-        from lmfit import minimize, Parameters
-    except (ImportError, ModuleNotFoundError) as e:
-        from plasmapy.optional_deps import lmfit_import_error
-
-        raise lmfit_import_error from e
-
     params = Parameters()
     params.add("alpha", value=alphaGuess, min=0.0)
     # calling minimize function from lmfit to fit by minimizing the residual
