@@ -1,5 +1,4 @@
 import astropy.units as u
-import collections
 import itertools
 import numpy as np
 import pytest
@@ -16,10 +15,9 @@ from plasmapy.particles import (
     mass_number,
     Particle,
     particle_symbol,
+    ParticleList,
 )
 from plasmapy.particles.exceptions import InvalidIsotopeError, ParticleError
-from plasmapy.particles.particle_collections import ParticleList
-from plasmapy.utils.pytest_helpers import run_test
 
 
 def check_abundances_consistency(
@@ -35,8 +33,7 @@ def check_abundances_consistency(
         f"log_abundances.keys(): {log_abundances.keys()}"
     )
 
-    for element in abundances.keys():
-        abundance_from_abundances = abundances[element]
+    for element, abundance_from_abundances in abundances.items():
         abundance_from_log_abundances = 10 ** log_abundances[element]
         assert np.isclose(
             abundance_from_abundances, abundance_from_log_abundances
@@ -44,8 +41,7 @@ def check_abundances_consistency(
 
 
 def has_attribute(attribute, tests_dict):
-    cases = [test for test in tests_dict.keys() if attribute in tests_dict[test].keys()]
-    if cases:
+    if cases := [test for test in tests_dict if attribute in tests_dict[test]]:
         return cases
     else:
         raise ValueError(f"No cases with attribute {attribute}")
@@ -61,8 +57,8 @@ tests = {
     },
     "quantities": {
         "inputs": {
-            "H": np.array([10, 90]) * u.m ** -3,
-            "He": np.array([1, 9, 0]) * u.m ** -3,
+            "H": np.array([10, 90]) * u.m**-3,
+            "He": np.array([1, 9, 0]) * u.m**-3,
         }
     },
     "just H": {"inputs": {"H": [0.1, 0.9]}},
@@ -70,19 +66,19 @@ tests = {
     "n0": {
         "inputs": {"He": [1, 0, 0], "H": [1, 0]},
         "abundances": {"H": 1, "He": 0.1},
-        "n0": 1e9 * u.cm ** -3,
+        "n0": 1e9 * u.cm**-3,
     },
     "T_e and n": {
         "inputs": {"H": [0.9, 0.1], "helium": [0.5, 0.3, 0.2]},
         "abundances": {"H": 1, "He": 0.1},
         "T_e": 1e4 * u.K,
-        "n0": 1e15 * u.m ** -3,
+        "n0": 1e15 * u.m**-3,
         "kappa": np.inf,
     },
     "log_abundances": {
         "inputs": {"H": [1, 0], "He": [1, 0, 0]},
         "log_abundances": {"H": 1, "He": 0},
-        "n0": 1e9 * u.cm ** -3,
+        "n0": 1e9 * u.cm**-3,
     },
     "elements & isotopes": {
         "inputs": {
@@ -91,7 +87,7 @@ tests = {
             "He-4": [0.29, 0.69, 0.02],
         },
         "abundances": {"H": 1, "He-3": 1e-7, "He-4": 0.1},
-        "n0": 1e12 * u.m ** -3,
+        "n0": 1e12 * u.m**-3,
     },
     "ordered elements -> inputs": {"inputs": ["O", "C", "H", "Fe", "Ar"]},
     "mixed and unordered elements and isotopes": {
@@ -99,13 +95,13 @@ tests = {
     },
     "number densities -> inputs": {
         "inputs": {
-            "H": np.array([2, 3]) * u.m ** -3,
-            "He": np.array([5, 7, 11]) * u.m ** -3,
+            "H": np.array([2, 3]) * u.m**-3,
+            "He": np.array([5, 7, 11]) * u.m**-3,
         }
     },
     "number densities and n are both inputs": {
-        "inputs": {"H": [0.1, 0.3] * u.cm ** -3},
-        "n0": 1e-5 * u.mm ** -3,
+        "inputs": {"H": [0.1, 0.3] * u.cm**-3},
+        "n0": 1e-5 * u.mm**-3,
     },
 }
 
@@ -161,9 +157,7 @@ class TestIonizationStateCollection:
         input_particles = tests[test_name]["inputs"].keys()
         particles = [Particle(input_particle) for input_particle in input_particles]
         expected_particles = {p.symbol for p in particles}
-        actual_particles = {
-            particle for particle in self.instances[test_name].ionic_fractions.keys()
-        }
+        actual_particles = set(self.instances[test_name].ionic_fractions)
 
         assert actual_particles == expected_particles, (
             f"For test='{test_name}', the following should be equal:\n"
@@ -297,7 +291,7 @@ class TestIonizationStateCollection:
     def test_getitem_element_intcharge(self, test_name):
         instance = self.instances[test_name]
         for particle in instance.base_particles:
-            for int_charge in range(0, atomic_number(particle) + 1):
+            for int_charge in range(atomic_number(particle) + 1):
                 actual = instance[particle, int_charge].ionic_fraction
                 expected = instance.ionic_fractions[particle][int_charge]
                 # We only need to check if one is broken
@@ -421,14 +415,14 @@ class TestIonizationStateCollectionDensities:
             "He": np.array([0.24, 0.37, 0.39]),
         }
         cls.abundances = {"H": 1.0, "He": 0.0835}
-        cls.n = 10 * u.m ** -3
+        cls.n = 10 * u.m**-3
 
         cls.expected_densities = {
-            "H": np.array([8.7, 1.3]) * u.m ** -3,
-            "He": np.array([0.2004, 0.30895, 0.32565]) * u.m ** -3,
+            "H": np.array([8.7, 1.3]) * u.m**-3,
+            "He": np.array([0.2004, 0.30895, 0.32565]) * u.m**-3,
         }
 
-        cls.expected_electron_density = 2.26025 * u.m ** -3
+        cls.expected_electron_density = 2.26025 * u.m**-3
         cls.states = IonizationStateCollection(
             cls.initial_ionfracs, abundances=cls.abundances, n0=cls.n
         )
@@ -459,7 +453,7 @@ class TestIonizationStateCollectionAttributes:
     def setup_class(cls):
         cls.elements = ["H", "He", "Li", "Fe"]
         cls.instance = IonizationStateCollection(cls.elements)
-        cls.new_n = 5.153 * u.cm ** -3
+        cls.new_n = 5.153 * u.cm**-3
 
     @pytest.mark.parametrize("uninitialized_attribute", ["T_e", "n0", "n_e"])
     def test_attribute_defaults_to_nan(self, uninitialized_attribute):
@@ -548,7 +542,7 @@ class TestIonizationStateCollectionAttributes:
         assert np.allclose(
             self.new_fractions, resulting_fractions
         ), "Ionic fractions for H not set using __setitem__."
-        assert "He" in self.instance.ionic_fractions.keys(), (
+        assert "He" in self.instance.ionic_fractions, (
             "He is missing in ionic_fractions after __setitem__ was "
             "used to set H ionic fractions."
         )
@@ -565,7 +559,7 @@ class TestIonizationStateCollectionAttributes:
             ("H", [0.5, 0.5, 0.0], ValueError),
             ("He", [0.5, 0.5], ValueError),
             ("He", [0.1, 0.9, 0.0, 0.0], ValueError),
-            ("He", [0.9, 0.1, 0.0] * u.m ** -2, ValueError),
+            ("He", [0.9, 0.1, 0.0] * u.m**-2, ValueError),
             ("He", [-0.01, 0.99, 0.02], ValueError),
             ("He", [1.01, -0.02, 0.01], ValueError),
         ],
@@ -588,8 +582,7 @@ class TestIonizationStateCollectionAttributes:
         new_abundances = {"H": 1, "He": 0.1, "Li": 1e-4, "Fe": 1e-5, "Au": 1e-8}
 
         log_new_abundances = {
-            element: np.log10(new_abundances[element])
-            for element in new_abundances.keys()
+            element: np.log10(new_abundances[element]) for element in new_abundances
         }
 
         try:
@@ -673,7 +666,7 @@ class TestIonizationStateCollectionAttributes:
             pytest.fail("Unable to set number density scaling factor attribute")
         if not u.quantity.allclose(self.instance.n0, self.new_n):
             pytest.fail("Number density scaling factor was not set correctly.")
-        if not self.instance.n0.unit == u.m ** -3:
+        if self.instance.n0.unit != u.m**-3:
             pytest.fail("Incorrect units for new number density.")
 
     def test_resetting_valid_densities(self):
@@ -724,7 +717,7 @@ class TestIonizationStateCollectionAttributes:
             )
 
     def test_that_iron_ionic_fractions_are_still_undefined(self):
-        assert "Fe" in self.instance.ionic_fractions.keys()
+        assert "Fe" in self.instance.ionic_fractions
         iron_fractions = self.instance.ionic_fractions["Fe"]
         assert len(iron_fractions) == atomic_number("Fe") + 1
         assert np.all(np.isnan(iron_fractions))
@@ -743,75 +736,6 @@ class TestIonizationStateCollectionAttributes:
         )
 
 
-IE = collections.namedtuple("IE", ["inputs", "expected_exception"])
-
-tests_for_exceptions = {
-    "wrong type": IE({"inputs": None}, ParticleError),
-    "not normalized": IE(
-        {"inputs": {"He": [0.4, 0.5, 0.0]}, "tol": 1e-9}, ParticleError
-    ),
-    "negative ionfrac": IE({"inputs": {"H": [-0.1, 1.1]}}, ParticleError),
-    "ion": IE({"inputs": {"H": [0.1, 0.9], "He+": [0.0, 0.9, 0.1]}}, ParticleError),
-    "repeat elements": IE(
-        {"inputs": {"H": [0.1, 0.9], "hydrogen": [0.2, 0.8]}}, ParticleError
-    ),
-    "isotope of element": IE(
-        {"inputs": {"H": [0.1, 0.9], "D": [0.2, 0.8]}}, ParticleError
-    ),
-    "negative abundance": IE(
-        {
-            "inputs": {"H": [0.1, 0.9], "He": [0.4, 0.5, 0.1]},
-            "abundances": {"H": 1, "He": -0.1},
-        },
-        ParticleError,
-    ),
-    "imaginary abundance": IE(
-        {
-            "inputs": {"H": [0.1, 0.9], "He": [0.4, 0.5, 0.1]},
-            "abundances": {"H": 1, "He": 0.1j},
-        },
-        ParticleError,
-    ),
-    "wrong density units": IE(
-        {
-            "inputs": {"H": [10, 90] * u.m ** -3, "He": [0.1, 0.9, 0] * u.m ** -2},
-            "abundances": {"H": 1, "He": 0.1},
-        },
-        ParticleError,
-    ),
-    "abundance redundance": IE(
-        {
-            "inputs": {"H": [10, 90] * u.m ** -3, "He": [0.1, 0.9, 0] * u.m ** -3},
-            "abundances": {"H": 1, "He": 0.1},
-        },
-        ParticleError,
-    ),
-    "abundance contradiction": IE(
-        {
-            "inputs": {"H": [10, 90] * u.m ** -3, "He": [0.1, 0.9, 0] * u.m ** -3},
-            "abundances": {"H": 1, "He": 0.11},
-        },
-        ParticleError,
-    ),
-    "kappa too small": IE({"inputs": ["H"], "kappa": 1.499999}, ParticleError),
-    "negative n": IE({"inputs": ["H"], "n0": -1 * u.cm ** -3}, ParticleError),
-    "negative T_e": IE({"inputs": ["H-1"], "T_e": -1 * u.K}, ParticleError),
-}
-
-
-@pytest.mark.parametrize("test_name", tests_for_exceptions.keys())
-def test_exceptions_upon_instantiation(test_name):
-    """
-    Test that appropriate exceptions are raised for inappropriate inputs
-    to IonizationStateCollection when first instantiated.
-    """
-    run_test(
-        IonizationStateCollection,
-        kwargs=tests_for_exceptions[test_name].inputs,
-        expected_outcome=tests_for_exceptions[test_name].expected_exception,
-    )
-
-
 class TestIonizationStateCollectionDensityEqualities:
     """
     Test that IonizationStateCollection instances are equal or not equal to each
@@ -827,10 +751,10 @@ class TestIonizationStateCollectionDensityEqualities:
 
         cls.ionic_fractions = {"H": [0.9, 0.1], "He": [0.99, 0.01, 0.0]}
         cls.abundances = {"H": 1, "He": 0.08}
-        cls.n = 5.3 * u.m ** -3
+        cls.n = 5.3 * u.m**-3
         cls.number_densities = {
             element: cls.ionic_fractions[element] * cls.n * cls.abundances[element]
-            for element in cls.ionic_fractions.keys()
+            for element in cls.ionic_fractions
         }
 
         # The keys that begin with 'ndens' have enough information to
@@ -851,7 +775,7 @@ class TestIonizationStateCollectionDensityEqualities:
 
         cls.instances = {
             key: IonizationStateCollection(**cls.dict_of_kwargs[key])
-            for key in cls.dict_of_kwargs.keys()
+            for key in cls.dict_of_kwargs
         }
 
     @pytest.mark.parametrize("test_key", ["ndens1", "ndens2"])
@@ -887,7 +811,7 @@ class TestIonizationStateCollectionDensityEqualities:
         provide ``number_densities`` is not equal to each instance that
         should not provide ``number_densities``.
         """
-        expect_equality = this[0:4] == that[0:4]
+        expect_equality = this[:4] == that[:4]
         are_equal = self.instances[this] == self.instances[that]
         if expect_equality != are_equal:
             print(f"{this} kwargs:\n {self.dict_of_kwargs[this]}\n")
@@ -903,7 +827,7 @@ class TestIonizationStateCollectionDensityEqualities:
 
 def test_number_density_assignment():
     instance = IonizationStateCollection(["H", "He"])
-    number_densities = [2, 3, 5] * u.m ** -3
+    number_densities = [2, 3, 5] * u.m**-3
     instance["He"] = number_densities
 
 
