@@ -9,13 +9,14 @@ __all__ = [
 ]
 
 import astropy.units as u
+import contextlib
 import numpy as np
 import pandas as pd
 import scipy.interpolate as interp
 import warnings
 import xarray as xr
 
-from abc import ABC
+from abc import ABC, abstractmethod
 from cached_property import cached_property
 from collections import namedtuple
 from scipy.spatial import distance
@@ -46,7 +47,6 @@ class AbstractGrid(ABC):
     as an `~numpy.ndarray`, while the units associated with each
     dimension are stored separately.
 
-
     There are two preferred methods to creating a grid object:
 
     1. Initializing the grid by providing three 3D
@@ -117,7 +117,7 @@ class AbstractGrid(ABC):
         RecognizedQuantity("x", "x spatial position", u.m),
         RecognizedQuantity("y", "y spatial position", u.m),
         RecognizedQuantity("z", "z spatial position", u.m),
-        RecognizedQuantity("rho", "Mass density", u.kg / u.m ** 3),
+        RecognizedQuantity("rho", "Mass density", u.kg / u.m**3),
         RecognizedQuantity("E_x", "Electric field (x component)", u.V / u.m),
         RecognizedQuantity("E_y", "Electric field (y component)", u.V / u.m),
         RecognizedQuantity("E_z", "Electric field (z component)", u.V / u.m),
@@ -177,30 +177,27 @@ class AbstractGrid(ABC):
             if rq not in self.quantities:
 
                 # If missing, warn user and then replace with an array of zeros
-                if replace_with_zeros:
-                    warnings.warn(
-                        f"{rq} is not specified for the provided grid."
-                        "This quantity will be assumed to be zero.",
-                        RuntimeWarning,
-                    )
-
-                    if rq in self.recognized_quantities.keys():
-                        unit = self.recognized_quantities[rq].unit
-                    else:
-                        raise KeyError(
-                            f"{rq} is not a recognized key, and "
-                            "so cannot be automatically assumed "
-                            "to be zero."
-                        )
-
-                    arg = {rq: np.zeros(self.shape) * unit}
-                    self.add_quantities(**arg)
-
-                else:
+                if not replace_with_zeros:
                     raise KeyError(
                         f"{rq} is not specified for the provided "
                         "grid but is required."
                     )
+                elif rq not in self.recognized_quantities:
+                    raise KeyError(
+                        f"{rq} is not a recognized key, and "
+                        "so cannot be automatically assumed "
+                        "to be zero."
+                    )
+
+                warnings.warn(
+                    f"{rq} is not specified for the provided grid."
+                    "This quantity will be assumed to be zero.",
+                    RuntimeWarning,
+                )
+
+                unit = self.recognized_quantities[rq].unit
+                arg = {rq: np.zeros(self.shape) * unit}
+                self.add_quantities(**arg)
 
     # *************************************************************************
     # Fundamental properties of the grid
@@ -214,7 +211,7 @@ class AbstractGrid(ABC):
         ax_units = self.units
         ax_dtypes = [self.ds[i].dtype for i in coords]
 
-        coord_lbls = [str(i) + ": " + str(j) for i, j in zip(coords, shape)]
+        coord_lbls = [f"{str(i)}: {str(j)}" for i, j in zip(coords, shape)]
 
         s = f"*** Grid Summary ***\n{type(self)}\n"
 
@@ -237,7 +234,7 @@ class AbstractGrid(ABC):
         nrkeys = [k for k in keys if k not in list(self.recognized_quantities.keys())]
 
         s += line_sep + "Recognized Quantities:\n"
-        if len(rkeys) == 0:
+        if not rkeys:
             s += "-None-\n"
         else:
             for key in rkeys:
@@ -247,7 +244,7 @@ class AbstractGrid(ABC):
                 s += f"\t-> {key} ({unit}) {dtype} {shape} \n"
 
         s += line_sep + "Unrecognized Quantities:\n"
-        if len(nrkeys) == 0:
+        if not nrkeys:
             s += "-None-\n"
         else:
             for key in nrkeys:
@@ -297,17 +294,15 @@ class AbstractGrid(ABC):
         Three grids of vertex positions (in each coordinate), each having
         shape (N0, N1, N2).
         """
-        if self.is_uniform:
-            pts0, pts1, pts2 = np.meshgrid(self.ax0, self.ax1, self.ax2, indexing="ij")
-            _grids = (pts0, pts1, pts2)
-        else:
-            _grids = (
+        if not self.is_uniform:
+            return (
                 self.ds["ax0"].data * self.unit0,
                 self.ds["ax1"].data * self.unit1,
                 self.ds["ax2"].data * self.unit2,
             )
 
-        return _grids
+        pts0, pts1, pts2 = np.meshgrid(self.ax0, self.ax1, self.ax2, indexing="ij")
+        return pts0, pts1, pts2
 
     @property
     def grid(self):
@@ -327,9 +322,7 @@ class AbstractGrid(ABC):
         grid[..., 0] = pts0
         grid[..., 1] = pts1
         grid[..., 2] = pts2
-        _grid = grid
-
-        return _grid
+        return grid
 
     @property
     def pts0(self):
@@ -381,7 +374,7 @@ class AbstractGrid(ABC):
             return self.units[0]
         else:
             raise ValueError(
-                "Array dimensions do not all have the same " f"units: {self.units}"
+                f"Array dimensions do not all have the same units: {self.units}"
             )
 
     # *************************************************************************
@@ -427,10 +420,7 @@ class AbstractGrid(ABC):
             )
 
         vals = self.ds.coords[ax_name].values
-        if si:
-            return vals * self.si_scale_factors[axis]
-        else:
-            return vals * self.units[axis]
+        return vals * self.si_scale_factors[axis] if si else vals * self.units[axis]
 
     def _get_dax(self, *, axis: int, si: bool = False):
         """
@@ -557,23 +547,6 @@ class AbstractGrid(ABC):
         """
         return self._get_dax(axis=2)
 
-    @property
-    def grid_resolution(self):
-        r"""
-        A scalar estimate of the grid resolution.
-
-        For uniform grids, this is the minima of [dax0, dax1, dax2].
-
-        For non-uniform grids, it is the closest spacing between any two points.
-        """
-
-        if self.is_uniform:
-            return min(self.dax0, self.dax1, self.dax2)
-        else:
-            distances = distance.cdist(self.grid, self.grid)
-            np.fill_diagonal(distances, np.inf)
-            return np.min(distances)
-
     # *************************************************************************
     # Loading and creating grids
     # *************************************************************************
@@ -592,12 +565,12 @@ class AbstractGrid(ABC):
         grid{0,1,2} : `~astropy.units.Quantity` array, shape (n0, n1, n2)
             Grids of coordinate positions.
 
-        **kwargs: `~astropy.units.Quantity` array, shape (n0, n1, n2)
+        **kwargs : `~astropy.units.Quantity` array, shape (n0, n1, n2)
             Quantities defined on the grid.
         """
 
         # Validate input
-        if not (pts0.shape == pts1.shape and pts0.shape == pts2.shape):
+        if pts0.shape != pts1.shape or pts0.shape != pts2.shape:
             raise ValueError(
                 "Provided arrays of grid points are of unequal "
                 f"shape: pts0 = {pts0.shape}, "
@@ -641,18 +614,18 @@ class AbstractGrid(ABC):
 
         Parameters
         ----------
-        key, array pairs as keyword arguments
+        **kwargs : key, array pairs
             The key will be used as the dataset key, while the array holds the
             quantity.
         """
 
-        for key in kwargs.keys():
+        for key in kwargs:
             quantity = kwargs[key]
 
             # Check key against a list of "known" keys with pre-defined
             # meanings (eg. E_x, n_e) and raise a warning if a "non-standard"
             # key is being used so the user is aware.
-            if key in self.recognized_quantities.keys():
+            if key in self.recognized_quantities:
                 try:
                     quantity.to(self.recognized_quantities[key].unit)
                 except u.UnitConversionError:
@@ -714,42 +687,77 @@ class AbstractGrid(ABC):
 
         Parameters
         ----------
-        start : number (`~astropy.units.Quantity`) or array of three of the same
+        start : number (`~astropy.units.Quantity`) or an array, list, or
+            tuple of three of the same.
             Starting values for each dimension. If one value is given,
             the same value will be used for all three dimensions.
 
-        stop : number (`~astropy.units..Quantity`) or array of three of the same
+        stop : number (`~astropy.units..Quantity`) or an array, list, or
+            tuple of three of the same.
             End values for each dimension. If one value is given,
             the same value will be used for all three dimensions.
 
-        num : `int` or `list` of three `int` objects, optional
+        num : `int` or `list` or `tuple` of three `int` objects, optional
             The number of points in each dimension. If a single integer is
             given, the same number of points will be used in each dimension.
             The default is 100.
 
-        **kwargs: Additional arguments
+        **kwargs : Additional arguments
             Any additional arguments will be passed directly to
             `numpy.linspace`.
         """
 
-        # If array of quantities are given instead of a list, convert
-        if isinstance(stop, u.Quantity) and stop.size == 3:
-            stop = list(stop)
-        elif isinstance(stop, u.Quantity) and stop.size == 1:
-            stop = [stop] * 3
+        # Store variables in dict for validation
+        var = {"stop": stop, "start": start, "num": num}
 
-        if isinstance(start, u.Quantity) and start.size > 1:
-            start = list(start)
-        elif isinstance(start, u.Quantity) and start.size == 1:
-            start = [start] * 3
+        # Ensure that start and stop end up as a list of three u.Quantity objs
+        # and num a list of three integers
+        # TODO python3.10: simplify using structural pattern matching
+        for k in ["start", "stop"]:
+            # Convert tuple to list
+            if isinstance(var[k], tuple):
+                var[k] = list(var[k])
 
-        if isinstance(num, (int, float)):
-            num = [int(num)] * 3
+            if isinstance(var[k], list):
+                if len(var[k]) == 1:
+                    var[k] = var[k] * 3
+
+                # Make sure it's a list of quantities
+                if not all(isinstance(v, u.Quantity) for v in var[k]):
+                    raise ValueError(
+                        f"The argument `{k}` must be an "
+                        "`astropy.units.Quantity` or a list of same, "
+                        f"but a {type(var[k])} was given."
+                    )
+            elif isinstance(var[k], u.Quantity):
+                # Extend to 3 elements if only one is given
+                # Case of >1 but != 3 is handled later
+                var[k] = [var[k]] * 3 if var[k].size == 1 else list(var[k])
+            else:
+                raise ValueError(
+                    f"The argument `{k}` must be an "
+                    "`astropy.units.Quantity` or a list of same, "
+                    f"but a {type(var[k])} was given."
+                )
+
+        # Convert tuple to list
+        if isinstance(var["num"], tuple):
+            var["num"] = list(var["num"])
+
+        if isinstance(var["num"], list):
+            if len(var["num"]) == 1:
+                var["num"] = var["num"] * 3
+        elif isinstance(var["num"], int):
+            var["num"] = [var["num"]] * 3
+        else:
+            raise ValueError(
+                f"The argument `num` must be an int or list of "
+                f"same, but a {type(var[k])} was given."
+            )
 
         # Check to make sure all lists now contain three values
         # (throws exception if user supplies a list of two, say)
-        var = {"stop": stop, "start": start, "num": num}
-        for k in var.keys():
+        for k in var:
             if len(var[k]) != 3:
                 raise ValueError(
                     f"{k} must be either a single value or a "
@@ -757,6 +765,11 @@ class AbstractGrid(ABC):
                     f"({len(var[k])} values were given)."
                 )
 
+        # Take variables back out of dict
+        start = var["start"]
+        stop = var["stop"]
+        num = var["num"]
+
         # Extract units from input arrays (if they are there), then
         # remove the units from those arrays
         units = []
@@ -770,13 +783,7 @@ class AbstractGrid(ABC):
                 stop[i] = stop[i].to(unit)
 
             except u.UnitConversionError:
-                raise ValueError(
-                    f"Units of {stop[i]} and " f" {unit} are not compatible"
-                )
-            except AttributeError:
-                raise AttributeError(
-                    "Start and stop values must be u.Quantity instances."
-                )
+                raise ValueError(f"Units of {stop[i]} and {unit} are not compatible")
 
             # strip units
             stop[i] = stop[i].value
@@ -854,35 +861,16 @@ class AbstractGrid(ABC):
 
         return np.where(on_grid == 0, True, False)
 
+    @abstractmethod
     def vector_intersects(self, p1, p2):
         r"""
         `True` if the vector from ``p1`` to ``p2`` intersects the grid,
         and `False` otherwise.
 
-        This is a standard ray-box intersection algorithm.
+        The definition of 'intersects' is determined by the implementation
+        for each subclass.
         """
-        p1, p2 = p1.si.value, p2.si.value
-        # Caclulate the minimum and maximum of each
-        Ax, Bx = np.min(self.pts0.si.value), np.max(self.pts0.si.value)
-        Ay, By = np.min(self.pts1.si.value), np.max(self.pts1.si.value)
-        Az, Bz = np.min(self.pts2.si.value), np.max(self.pts2.si.value)
-        A = np.array([Ax, Ay, Az])
-        B = np.array([Bx, By, Bz])
-
-        # Calculate the equation of the line from p1 to p2 such that
-        # r = p1 + t*D
-        D = np.abs(p2 - p1)
-
-        # Calculate the intersection points. These operations are just vectorized
-        # for convenience. Ignore div-by-zero: outputting infty's here is fine.
-        with np.errstate(divide="ignore"):
-            Tmin = (A - p1) / D
-            Tmax = (B - p1) / D
-
-        Tmin = np.max(Tmin)
-        Tmax = np.min(Tmax)
-
-        return Tmin < Tmax
+        ...
 
     # *************************************************************************
     # Interpolators
@@ -915,112 +903,9 @@ class AbstractGrid(ABC):
         Create a list of the units corresponding to the last dimension
         in the `_interp_quantities` array.
         """
-        _interp_units = []
-        for j, arg in enumerate(self._interp_args):
-            _interp_units.append(self.ds[arg].attrs["unit"])
-
-        return _interp_units
-
-    @property
-    def interpolator(self):
-        r"""
-        A nearest-neighbor interpolator that returns the nearest grid index
-        to a position.
-        """
-        if self._interpolator is None:
-            if self.is_uniform:
-                self._make_uniform_grid_interpolator()
-            else:
-                self._make_nonuniform_grid_interpolator()
-
-        return self._interpolator
-
-    def _make_uniform_grid_interpolator(self):
-        r"""
-        Initializes a nearest-neighbor interpolator that returns the nearest
-        grid indices for a given position (given in SI units).
-
-        This function works on a uniformly spaced grid.
-        """
-        # Create a grid of indices for use in interpolation
-        n0, n1, n2 = self.shape
-        indgrid = np.indices([n0, n1, n2])
-        indgrid = np.moveaxis(indgrid, 0, -1)
-
-        # Create an input array of grid positions
-        pts = (
-            self.ax0.si.value,
-            self.ax1.si.value,
-            self.ax2.si.value,
-        )
-
-        self._interpolator = interp.RegularGridInterpolator(
-            pts, indgrid, method="nearest", bounds_error=False, fill_value=np.nan
-        )
-
-    def _make_nonuniform_grid_interpolator(self):
-        r"""
-        Initializes a nearest-neighbor interpolator that returns the nearest
-        grid indices for a given position (given in SI units).
-
-        This function works on unstructured (non-uniform) data.
-        """
-
-        # Make an array of point positions
-        pts0, pts1, pts2 = self.pts0.si.value, self.pts1.si.value, self.pts2.si.value
-        pts = np.array([pts0, pts1, pts2])
-        pts = np.moveaxis(pts, 0, 1)
-
-        # Create a flat array of indices corresponding to those positions
-        indgrid = np.arange(self.shape[0])
-
-        self._interpolator = interp.NearestNDInterpolator(pts, indgrid)
-
-    def interpolate_indices(self, pos: Union[np.ndarray, u.Quantity]):
-        r"""
-        Interpolate the nearest grid indices to a position using a
-        nearest-neighbor interpolator.
-
-        Parameters
-        ----------
-        pos : `~numpy.ndarray` or `~astropy.units.Quantity` array, shape (n,3)
-            An array of positions in space, where the second dimension
-            corresponds to the three dimensions of the grid. If a
-            `~numpy.ndarray` is provided, units will be assumed to match
-            those of the grid.
-
-        Returns
-        -------
-        i : `~numpy.ndarray`, shape (n,3)
-            An array of indices corresponding to the positions such that
-            ``i[n,:] = ix,iy,iz`` such that ``grid[ix,iy,iz,:]`` ∼ ``pos[n,:]``
-
-        """
-        # Condition pos
-        # If a single point was given, add empty dimension
-        if pos.ndim == 1:
-            pos = np.reshape(pos, [1, 3])
-        pos2 = np.zeros(pos.shape)
-        # Convert position to SI and then strip units
-        if hasattr(pos, "unit"):
-            pos2 = pos.si.value
-        else:
-            for i in range(3):
-                pos2[:, i] = (pos[:, i] * self.units[i]).si.value
-
-        # Interpolate indices
-        i = self.interpolator(pos2)
-
-        # TODO: Check interpolated positions and reject any (set to NaN)
-        # that are above a certain tolerance distance?
-        # currently the nonuniform interpolator can't tell when a value
-        # is out of bounds...
-
-        # Note: i contains nan values which must be replaced with 0's with
-        # appropriate units in the second layer interpolator functions.
-
-        return i
+        return [self.ds[arg].attrs["unit"] for arg in self._interp_args]
 
+    @abstractmethod
     def nearest_neighbor_interpolator(
         self, pos: Union[np.ndarray, u.Quantity], *args, persistent=False
     ):
@@ -1047,87 +932,11 @@ class AbstractGrid(ABC):
             ``persistent`` overrides to `False` if the arguments list
             has changed since the last call.
         """
-        # pos is validated in interpolate_indices
+        ...
 
-        # Validate args
-        # must be np.ndarray or u.Quantity arrays of same shape as grid
-        for arg in args:
-
-            if arg not in self.quantities:
-                raise KeyError(
-                    "Quantity arguments must correspond to "
-                    "DataArrays in the DataSet. "
-                    f"{arg} was not found. "
-                    f"Existing keys are: {self.quantities}"
-                )
-
-        # If persistent, double check the arguments list hasn't changed
-        # If they have, run as non-persistent this time
-        if persistent and args != self._interp_args:
-            persistent = False
-
-        # Update _interp_args variable
-        self._interp_args = args
-
-        # Interpolate the nearest-neighbor indices
-        i = self.interpolate_indices(pos)
-        nargs = len(args)
-
-        # Get the indices that are equal to nan (fill values), then set
-        # their values to 0. They will be over-written after the interpolation
-
-        # Nan array is shape [n] and is 1 if none of the indices for a
-        # position are NaN, and 0 otherwise.
-
-        # i has different shape for non-uniform grids
-        if self.is_uniform:
-            nan_mask = np.where(np.isnan(np.sum(i, axis=1)), 0, 1)
-        else:
-            nan_mask = np.where(np.isnan(i), 0, 1)
-
-        # Replace all NaNs temporarily with 0
-        i = np.where(np.isnan(i), 0, i)
-        i = i.astype(np.int32)  # Cast as integers
-
-        # If not persistent, clear the cached properties so they are re-created
-        # when called below
-        if not persistent:
-            try:
-                del self._interp_quantities
-            except AttributeError:
-                pass
-            try:
-                del self._interp_units
-            except AttributeError:
-                pass
-
-        # Fetch the values at those indices from each quantity
-        if self.is_uniform:
-            values = self._interp_quantities[i[:, 0], i[:, 1], i[:, 2], :]
-        else:
-            values = self._interp_quantities[i]
-
-        # Apply the NaN mask (set any values that were out of bounds
-        # to zero)
-        values *= np.outer(nan_mask, np.ones(nargs))
-
-        # Split output array into arrays with units
-        # Apply units to output arrays
-        output = []
-        for i in range(nargs):
-            output.append(values[:, i] * self._interp_units[i])
-
-        if len(output) == 1:
-            return output[0]
-        else:
-            return tuple(output)
-
-    def volume_averaged_interpolator(
-        self, pos: Union[np.ndarray, u.Quantity], *args, persistent=False
-    ):
+    def _persistent_interpolator_setup(self, pos, args, persistent):
         r"""
-        Interpolate values on the grid using a volume-averaged scheme with
-        no higher-order weighting.
+        Setup common to all persistent interpolators.
 
         Parameters
         ----------
@@ -1137,7 +946,7 @@ class AbstractGrid(ABC):
             `~numpy.ndarray` is provided, units will be assumed to match
             those of the grid.
 
-        *args : `str`
+        args : `str`
             Strings that correspond to DataArrays in the dataset
 
         persistent : `bool`
@@ -1147,55 +956,38 @@ class AbstractGrid(ABC):
             interpolations are performed on the same grid in a loop.
             ``persistent`` overrides to `False` if the arguments list
             has changed since the last call.
+
+        Returns
+        -------
+
+        pos: `~numpy.ndarray`
+            Position array with dimensions fixed, units converted to
+            standard and stripped.
+
+        args : `str`
+            Strings that correspond to DataArrays in the dataset
+
+        persistent : `bool`
+            If `True`, the interpolator will assume the grid and its
+            contents have not changed since the last interpolation. This
+            substantially speeds up the interpolation when many
+            interpolations are performed on the same grid in a loop.
+            ``persistent`` overrides to `False` if the arguments list
+            has changed since the last call.
+
+        Raises
+        ------
+
+        KeyError
+            A KeyError is raised if one of the args does not correspond
+            to a DataArray in the DataSet.
         """
 
-        raise NotImplementedError(
-            "Volume-averaged interpolator is not yet " "implemented for this grid type."
-        )
-
-
-class CartesianGrid(AbstractGrid):
-    r"""A uniformly spaced Cartesian grid."""
-
-    def _validate(self):
-        # Check that all units are lengths
-        for i in range(3):
-            try:
-                self.units[i].to(u.m)
-            except u.UnitConversionError:
-                raise ValueError(
-                    "Units of grid are not valid for a Cartesian "
-                    f"grid: {self.units}."
-                )
-
-    @modify_docstring(prepend=AbstractGrid.volume_averaged_interpolator.__doc__)
-    def volume_averaged_interpolator(
-        self, pos: Union[np.ndarray, u.Quantity], *args, persistent=False
-    ):
-        """
-        Notes
-        -----
-
-        This interpolator approximates the value of a quantity at a given
-        interpolation point using a weighted sum of the values at the eight grid
-        vertices that surround the point. The weighting factors are calculated by
-        defining a volume :math:`dx \\times dy \\times dz`
-        (where :math:`dx`, :math:`dy`, and :math:`dz` are the grid
-        spacings in each direction) around each grid vertex and around the
-        interpolation point. The contribution of each grid vertex is then
-        weighted by the fraction of the volume surrounding the interpolation
-        point that overlaps the volume surrounding that vertex. This effectively
-        introduces a linear interpolation between grid vertices.
-
-        This implementation of this algorithm assumes that the grid is uniformly
-        spaced and Cartesian.
-        """
-
+        # Condition pos
         if isinstance(pos, u.Quantity):
             pos = pos.to(u.m).value
         elif self.unit != u.m:
             pos *= self.unit.si.scale
-
         # If a single point was given, add empty dimension
         if pos.ndim == 1:
             pos = np.reshape(pos, [1, 3])
@@ -1222,16 +1014,178 @@ class CartesianGrid(AbstractGrid):
         # If not persistent, clear the cached properties so they are re-created
         # when called below
         if not persistent:
-            try:
+            with contextlib.suppress(AttributeError):
                 del self._interp_quantities
-            except AttributeError:
-                pass
-            try:
+            with contextlib.suppress(AttributeError):
                 del self._interp_units
-            except AttributeError:
-                pass
 
-        # -- begin averaging --
+        return pos, args, persistent
+
+
+def _fast_nearest_neighbor_interpolate(pos, ax):
+    """
+    This function finds the indices in the axis 'ax' that are closest to the
+    values in the array 'pos'
+
+    Assumes the axis 'ax' is sorted in ascending order.
+
+    """
+    # Find the index where each position would be inserted into the axis.
+    # This is equivalent to a nearest neighbor interpolation but always
+    # rounding to the next highest axis point.
+    indices = np.searchsorted(ax, pos)
+
+    # searchsorted can return an out-of-bound index on the top end, so replace
+    # that point with the closest in bound index
+    indices = np.where(indices == ax.size, ax.size - 1, indices)
+
+    # For any points that are closer to the point below than the point above,
+    # correct the index
+    indices = np.where(
+        np.abs(ax[indices] - pos) > np.abs(ax[indices - 1] - pos), indices - 1, indices
+    )
+    return indices
+
+
+class CartesianGrid(AbstractGrid):
+    r"""A uniformly spaced Cartesian grid."""
+
+    def _validate(self):
+        # Check that all units are lengths
+        for i in range(3):
+            try:
+                self.units[i].to(u.m)
+            except u.UnitConversionError:
+                raise ValueError(
+                    "Units of grid are not valid for a Cartesian "
+                    f"grid: {self.units}."
+                )
+
+    @property
+    def grid_resolution(self):
+        r"""
+        A scalar estimate of the grid resolution, calculated as the
+        the minima of [dax0, dax1, dax2].
+
+        """
+        return min(self.dax0, self.dax1, self.dax2)
+
+    def vector_intersects(self, p1, p2):
+        r"""
+        `True` if the vector from ``p1`` to ``p2`` intersects the grid,
+        and `False` otherwise.
+
+        This is a standard ray-box intersection algorithm.
+        """
+        p1, p2 = p1.si.value, p2.si.value
+        # Calculate the minimum and maximum of each
+        Ax, Bx = np.min(self.pts0.si.value), np.max(self.pts0.si.value)
+        Ay, By = np.min(self.pts1.si.value), np.max(self.pts1.si.value)
+        Az, Bz = np.min(self.pts2.si.value), np.max(self.pts2.si.value)
+        A = np.array([Ax, Ay, Az])
+        B = np.array([Bx, By, Bz])
+
+        # Calculate the equation of the line from p1 to p2 such that
+        # r = p1 + t*D
+        D = np.abs(p2 - p1)
+
+        # Calculate the intersection points. These operations are just vectorized
+        # for convenience. Ignore div-by-zero: outputting infty's here is fine.
+        with np.errstate(divide="ignore"):
+            Tmin = (A - p1) / D
+            Tmax = (B - p1) / D
+
+        Tmin = np.max(Tmin)
+        Tmax = np.min(Tmax)
+
+        return Tmin < Tmax
+
+    @modify_docstring(prepend=AbstractGrid.nearest_neighbor_interpolator.__doc__)
+    def nearest_neighbor_interpolator(
+        self, pos: Union[np.ndarray, u.Quantity], *args, persistent=False
+    ):
+        r""" """
+
+        # Shared setup
+        pos, args, persistent = self._persistent_interpolator_setup(
+            pos, args, persistent
+        )
+
+        ax0, ax1, ax2 = self._ax0_si, self._ax1_si, self._ax2_si
+
+        # Find particles that are off the grid
+        mask_particle_off = (
+            (pos[:, 0] < ax0.min())
+            | (pos[:, 0] > ax0.max())
+            | (pos[:, 1] < ax1.min())
+            | (pos[:, 1] > ax1.max())
+            | (pos[:, 2] < ax2.min())
+            | (pos[:, 2] > ax2.max())
+        )
+
+        # Interpolate nearest index to each point along each axis
+        i0 = _fast_nearest_neighbor_interpolate(pos[:, 0], ax0)
+        i1 = _fast_nearest_neighbor_interpolate(pos[:, 1], ax1)
+        i2 = _fast_nearest_neighbor_interpolate(pos[:, 2], ax2)
+
+        vals = self._interp_quantities[i0, i1, i2, :]
+
+        # Replace values of off-grid particles with NaN
+        vals[mask_particle_off, :] = np.nan
+
+        # Split output array into arrays with units
+        # Apply units to output arrays
+        output = [
+            vals[..., index] * self._interp_units[index] for index, _ in enumerate(args)
+        ]
+        return output[0] if len(output) == 1 else tuple(output)
+
+    def volume_averaged_interpolator(
+        self, pos: Union[np.ndarray, u.Quantity], *args, persistent=False
+    ):
+        r"""
+        Interpolate values on the grid using a volume-averaged scheme with
+        no higher-order weighting.
+
+        Parameters
+        ----------
+        pos : `~numpy.ndarray` or `~astropy.units.Quantity` array, shape (n,3)
+            An array of positions in space, where the second dimension
+            corresponds to the three dimensions of the grid. If a
+            `~numpy.ndarray` is provided, units will be assumed to match
+            those of the grid.
+
+        *args : `str`
+            Strings that correspond to DataArrays in the dataset
+
+        persistent : `bool`
+            If `True`, the interpolator will assume the grid and its
+            contents have not changed since the last interpolation. This
+            substantially speeds up the interpolation when many
+            interpolations are performed on the same grid in a loop.
+            ``persistent`` overrides to `False` if the arguments list
+            has changed since the last call.
+
+        Notes
+        -----
+        This interpolator approximates the value of a quantity at a given
+        interpolation point using a weighted sum of the values at the eight grid
+        vertices that surround the point. The weighting factors are calculated by
+        defining a volume :math:`dx \\times dy \\times dz`
+        (where :math:`dx`, :math:`dy`, and :math:`dz` are the grid
+        spacings in each direction) around each grid vertex and around the
+        interpolation point. The contribution of each grid vertex is then
+        weighted by the fraction of the volume surrounding the interpolation
+        point that overlaps the volume surrounding that vertex. This effectively
+        introduces a linear interpolation between grid vertices.
+
+        This implementation of this algorithm assumes that the grid is uniformly
+        spaced and Cartesian.
+        """
+        # Shared setup
+        pos, args, persistent = self._persistent_interpolator_setup(
+            pos, args, persistent
+        )
 
         nparticles = pos.shape[0]
         nargs = len(args)
@@ -1243,9 +1197,15 @@ class CartesianGrid(AbstractGrid):
 
         # find cell nearest to each position
         nearest_neighbor_index = np.zeros((nparticles, 3), dtype=np.int32)
-        nearest_neighbor_index[..., 0] = np.abs(pos[:, 0, None] - ax0).argmin(axis=1)
-        nearest_neighbor_index[..., 1] = np.abs(pos[:, 1, None] - ax1).argmin(axis=1)
-        nearest_neighbor_index[..., 2] = np.abs(pos[:, 2, None] - ax2).argmin(axis=1)
+        nearest_neighbor_index[..., 0] = _fast_nearest_neighbor_interpolate(
+            pos[:, 0], ax0
+        )
+        nearest_neighbor_index[..., 1] = _fast_nearest_neighbor_interpolate(
+            pos[:, 1], ax1
+        )
+        nearest_neighbor_index[..., 2] = _fast_nearest_neighbor_interpolate(
+            pos[:, 2], ax2
+        )
 
         # Create a mask for positions that are off the grid. The values at
         # these points will be set to zero later.
@@ -1370,6 +1330,48 @@ class NonUniformCartesianGrid(AbstractGrid):
                     f"grid: {self.units}."
                 )
 
+    @property
+    def grid_resolution(self):
+        r"""
+        A scalar estimate of the grid resolution, calculated as the
+        closest spacing between any two points.
+        """
+        distances = distance.cdist(self.grid, self.grid)
+        np.fill_diagonal(distances, np.inf)
+        return np.min(distances) * self.unit
+
+    def vector_intersects(self, p1, p2):
+        r"""
+        `True` if the vector from ``p1`` to ``p2`` intersects the grid,
+        and `False` otherwise. The grid is defined by a cube extending in
+        each dimension from the minimum value of the grid to the maximum value
+        of the grid in that dimension.
+
+        This is a standard ray-box intersection algorithm.
+        """
+        p1, p2 = p1.si.value, p2.si.value
+        # Calculate the minimum and maximum of each
+        Ax, Bx = np.min(self.pts0.si.value), np.max(self.pts0.si.value)
+        Ay, By = np.min(self.pts1.si.value), np.max(self.pts1.si.value)
+        Az, Bz = np.min(self.pts2.si.value), np.max(self.pts2.si.value)
+        A = np.array([Ax, Ay, Az])
+        B = np.array([Bx, By, Bz])
+
+        # Calculate the equation of the line from p1 to p2 such that
+        # r = p1 + t*D
+        D = np.abs(p2 - p1)
+
+        # Calculate the intersection points. These operations are just vectorized
+        # for convenience. Ignore div-by-zero: outputting infty's here is fine.
+        with np.errstate(divide="ignore"):
+            Tmin = (A - p1) / D
+            Tmax = (B - p1) / D
+
+        Tmin = np.max(Tmin)
+        Tmax = np.min(Tmax)
+
+        return Tmin < Tmax
+
     def _make_mesh(self, start, stop, num, **kwargs):
         r"""
         Creates mesh as part of ``_make_grid()``. Separated into its own
@@ -1386,3 +1388,61 @@ class NonUniformCartesianGrid(AbstractGrid):
         arr0, arr1, arr2 = np.meshgrid(ax0, ax1, ax2, indexing="ij")
 
         return arr0, arr1, arr2
+
+    @cached_property
+    def _nearest_neighbor_interpolator(self):
+        """
+        Creates a nearest neighbor interpolator object for this grid, which can
+        then be called repeatedly.
+
+        """
+
+        indgrid = np.arange(self.grid.shape[0])
+
+        interpolator = interp.NearestNDInterpolator(self.grid.to(u.m).value, indgrid)
+        return interpolator
+
+    @modify_docstring(prepend=AbstractGrid.nearest_neighbor_interpolator.__doc__)
+    def nearest_neighbor_interpolator(
+        self, pos: Union[np.ndarray, u.Quantity], *args, persistent=False
+    ):
+        r""" """
+        # Shared setup
+        pos, args, persistent = self._persistent_interpolator_setup(
+            pos, args, persistent
+        )
+
+        # Clear additional property that is not handled in the
+        # _persistant_interpolator_setup function because it is unique
+        # to this non_uniform grid.
+        if not persistent:
+            with contextlib.suppress(AttributeError):
+                del self._nearest_neighbor_interpolator
+
+        pts0 = self.pts0.to(u.m).value
+        pts1 = self.pts1.to(u.m).value
+        pts2 = self.pts2.to(u.m).value
+
+        i = self._nearest_neighbor_interpolator(pos)
+
+        vals = self._interp_quantities[i, :]
+
+        mask_particle_off = (
+            (pos[:, 0] < pts0.min())
+            | (pos[:, 0] > pts0.max())
+            | (pos[:, 1] < pts1.min())
+            | (pos[:, 1] > pts1.max())
+            | (pos[:, 2] < pts2.min())
+            | (pos[:, 2] > pts2.max())
+        )
+
+        vals[mask_particle_off] = np.nan
+
+        output = []
+        for arg in range(len(args)):
+            output.append(vals[:, arg] * self._interp_units[arg])
+
+        if len(output) == 1:
+            return output[0]
+        else:
+            return tuple(output)
