@@ -7,6 +7,7 @@ __all__ = [
     "check_values",
     "check_units",
     "deprecated",
+    "bind_lite_func",
     "modify_docstring",
     "preserve_signature",
     "validate_quantities",
@@ -27,4 +28,5 @@ from plasmapy.utils.decorators.checks import (
 from plasmapy.utils.decorators.converter import angular_freq_to_hz
 from plasmapy.utils.decorators.deprecation import deprecated
 from plasmapy.utils.decorators.helpers import modify_docstring, preserve_signature
+from plasmapy.utils.decorators.lite_func import bind_lite_func
 from plasmapy.utils.decorators.validators import validate_quantities, ValidateQuantities
