@@ -399,14 +399,14 @@ class TestValidateQuantities:
                 "raises": u.UnitTypeError,
             },
             {
-                "descr": "decomposed units are still covnerted",
+                "descr": "decomposed units are still converted",
                 "setup": {
                     "function": self.foo,
-                    "args": (2 * u.kg * u.m / u.s ** 2,),
+                    "args": (2 * u.kg * u.m / u.s**2,),
                     "kwargs": {},
                     "validations": {"x": u.N},
                 },
-                "output": (2 * u.kg * u.m / u.s ** 2).to(u.N),
+                "output": (2 * u.kg * u.m / u.s**2).to(u.N),
                 "extra assert": lambda x: x.unit.to_string() == u.N.to_string(),
             },
         ]
