@@ -29,7 +29,7 @@ class ValidateQuantities(CheckUnits, CheckValues):
 
     **validations: dictionary of validation specifications
         Specifications for unit and value validations on the input arguments of the
-        function being wrapped.  Each keyword argument in `validations` is the
+        function being wrapped.  Each keyword argument in ``validations`` is the
         name of a function argument to be validated and the keyword value contains
         the unit and value validation specifications.
 
@@ -38,7 +38,7 @@ class ValidateQuantities(CheckUnits, CheckValues):
         Unit and value validations can be defined by passing one of the astropy
         :mod:`~astropy.units`, a list of astropy units, or a dictionary containing
         the keys defined below.  Units can also be defined with function annotations,
-        but must be consistent with decorator `**validations` arguments if used
+        but must be consistent with decorator ``**validations`` arguments if used
         concurrently.  If a key is omitted, then the default value will be assumed.
 
         ====================== ======= ================================================
@@ -62,12 +62,12 @@ class ValidateQuantities(CheckUnits, CheckValues):
 
     Notes
     -----
-    * Validation of function arguments `*args` and `**kwargs` is not supported.
+    * Validation of function arguments ``*args`` and ``**kwargs`` is not supported.
     * `None` values will pass when `None` is included in the list of specified units,
-      is set as a default value for the function argument, or `none_shall_pass` is
-      set to `True`.  If `none_shall_pass` is doubly/triply defined through the
+      is set as a default value for the function argument, or ``none_shall_pass`` is
+      set to `True`.  If ``none_shall_pass`` is doubly/triply defined through the
       mentioned options, then they all must be consistent with each other.
-    * If units are not specified in `validations`, then the decorator will attempt
+    * If units are not specified in ``validations``, then the decorator will attempt
       to identify desired units by examining the function annotations.
 
     Examples
@@ -165,6 +165,8 @@ class ValidateQuantities(CheckUnits, CheckValues):
 
     def __call__(self, f):
         """
+        Decorate a function.
+
         Parameters
         ----------
         f
@@ -173,7 +175,7 @@ class ValidateQuantities(CheckUnits, CheckValues):
         Returns
         -------
         function
-            wrapped function of `f`
+            wrapped function of ``f``
         """
         self.f = f
         wrapped_sign = inspect.signature(f)
@@ -386,7 +388,7 @@ class ValidateQuantities(CheckUnits, CheckValues):
 
 def validate_quantities(func=None, validations_on_return=None, **validations):
     """
-    A decorator to 'validate' -- control and convert -- the units and values
+    A decorator to 'validate' — control and convert — the units and values
     of input and return arguments to a function or method.  Arguments are expected to
     be astropy :class:`~astropy.units.quantity.Quantity` objects.
 
@@ -402,7 +404,7 @@ def validate_quantities(func=None, validations_on_return=None, **validations):
 
     **validations: dictionary of validation specifications
         Specifications for unit and value validations on the input arguments of the
-        function being wrapped.  Each keyword argument in `validations` is the
+        function being wrapped.  Each keyword argument in ``validations`` is the
         name of a function argument to be validated and the keyword value contains
         the unit and value validation specifications.
 
@@ -411,7 +413,7 @@ def validate_quantities(func=None, validations_on_return=None, **validations):
         Unit and value validations can be defined by passing one of the astropy
         :mod:`~astropy.units`, a list of astropy units, or a dictionary containing
         the keys defined below.  Units can also be defined with function annotations,
-        but must be consistent with decorator `**validations` arguments if used
+        but must be consistent with decorator ``**validations`` arguments if used
         concurrently.  If a key is omitted, then the default value will be assumed.
 
         ====================== ======= ================================================
@@ -435,12 +437,12 @@ def validate_quantities(func=None, validations_on_return=None, **validations):
 
     Notes
     -----
-    * Validation of function arguments `*args` and `**kwargs` is not supported.
+    * Validation of function arguments ``*args`` and ``**kwargs`` is not supported.
     * `None` values will pass when `None` is included in the list of specified units,
-      is set as a default value for the function argument, or `none_shall_pass` is
-      set to `True`.  If `none_shall_pass` is doubly/triply defined through the
+      is set as a default value for the function argument, or ``none_shall_pass`` is
+      set to `True`.  If ``none_shall_pass`` is doubly/triply defined through the
       mentioned options, then they all must be consistent with each other.
-    * If units are not specified in `validations`, then the decorator will attempt
+    * If units are not specified in ``validations``, then the decorator will attempt
       to identify desired units by examining the function annotations.
     * Full functionality is defined by the class :class:`ValidateQuantities`.
 
